@@ -58,7 +58,7 @@ end
 def match_ghdb(ghdb, body, _meta, _status, base_uri)
   # this could be made faster by creating code to eval once for each plugin
 
-  pp 'match_ghdb', ghdb if $verbose > 2
+  debug("match_ghdb: #{ghdb}")
 
   # take a GHDB string and turn it into code to be evaluated
   matches = [] # fill with true or false. succeeds if all true
@@ -96,7 +96,7 @@ def match_ghdb(ghdb, body, _meta, _status, base_uri)
 
   remaining_words = s.scan(/([^ "]+)|("[^"]+")/i).flatten.compact.each { |w| w.delete!('"') }.sort.uniq
 
-  pp 'Remaining GHDB words', remaining_words if $verbose > 2
+  debug("Remaining GHDB words: #{remaining_words}")
 
   remaining_words.each do |w|
     # does it start with a - ?
@@ -109,7 +109,7 @@ def match_ghdb(ghdb, body, _meta, _status, base_uri)
     end
   end
 
-  pp matches if $verbose > 2
+  debug("matches: #{matches}")
 
   # if all matcbhes are true, then true
   if matches.uniq == [true]
@@ -275,6 +275,22 @@ class Target
       raise err
     end
 
+    # Merge cookies from jar with user-provided cookies
+    if defined?($COOKIE_JAR) && $COOKIE_JAR && (!defined?($NO_COOKIES) || !$NO_COOKIES)
+      jar_cookies = $COOKIE_JAR.cookies_for_request(@uri.to_s)
+      
+      if jar_cookies
+        existing_cookies = $CUSTOM_HEADERS['Cookie']
+        
+        if existing_cookies && !existing_cookies.empty?
+          # Combine: user cookies take precedence
+          $CUSTOM_HEADERS['Cookie'] = "#{existing_cookies}; #{jar_cookies}"
+        else
+          $CUSTOM_HEADERS['Cookie'] = jar_cookies
+        end
+      end
+    end
+
     begin
       if $USE_PROXY == true
         http = ExtendedHTTP::Proxy($PROXY_HOST, $PROXY_PORT, $PROXY_USER, $PROXY_PASS).new(@uri.host, @uri.port)
@@ -310,6 +326,33 @@ class Target
 
       req.basic_auth $BASIC_AUTH_USER, $BASIC_AUTH_PASS if $BASIC_AUTH_USER
 
+      # Log HTTP request details for debug mode
+      request_details = []
+      request_details << "\n" + "=" * 60
+      request_details << "HTTP REQUEST"
+      request_details << "=" * 60
+      request_details << "#{options[:method]} #{getthis} HTTP/1.1"
+      request_details << "Host: #{@uri.host}#{@uri.port != (@uri.scheme == 'https' ? 443 : 80) ? ":#{@uri.port}" : ''}"
+      
+      # Show custom headers
+      $CUSTOM_HEADERS.each do |key, value|
+        request_details << "#{key}: #{value}"
+      end
+      
+      # Show basic auth header if present
+      if $BASIC_AUTH_USER
+        request_details << "Authorization: Basic [REDACTED]"
+      end
+      
+      # Show POST data if present
+      if options[:method] == 'POST' && options[:data]
+        request_details << "\n[POST Data]"
+        request_details << options[:data].inspect
+      end
+      request_details << "=" * 60
+      
+      debug(request_details.join("\n"))
+
       res = http.request(req)
       @raw_headers = http.raw.join("\n")
       @headers = {}
@@ -326,8 +369,35 @@ class Target
 
       @headers['set-cookie'] = res.get_fields('set-cookie').join("\n") unless @headers['set-cookie'].nil?
 
+      # Extract cookies to @cookies array (existing functionality)
+      @cookies = res.get_fields('set-cookie') || []
+
+      # Store cookies from response in the cookie jar
+      if defined?($COOKIE_JAR) && $COOKIE_JAR && (!defined?($NO_COOKIES) || !$NO_COOKIES)
+        if @headers['set-cookie']
+          $COOKIE_JAR.add_cookies(@headers['set-cookie'], @uri.to_s)
+          # Display cookie jar contents in debug mode
+          $COOKIE_JAR.display_cookies if defined?(debug) && $verbose && $verbose > 2
+        end
+      end
+
       @status = res.code.to_i
-      puts @uri.to_s + " [#{status}]" if $verbose > 1
+      
+      # Log HTTP response details for debug mode
+      response_details = []
+      response_details << "\nHTTP RESPONSE"
+      response_details << "=" * 60
+      response_details << "HTTP/1.1 #{@status} #{res.message}"
+      res.each_header do |key, value|
+        response_details << "#{key}: #{value}"
+      end
+      response_details << "=" * 60
+      response_details << "Response body length: #{@body ? @body.length : 0} bytes"
+      response_details << "=" * 60 + "\n"
+      
+      debug(response_details.join("\n"))
+      
+      debug("#{@uri} [#{status}]")
 
     rescue StandardError => err
       raise err
