@@ -13,15 +13,18 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with WhatWeb.  If not, see <http://www.gnu.org/licenses/>
+# along with WhatWeb.  If not, see <http://www.gnu.org/licenses/>.
 
-#
 module WhatWeb
   class Redirect
     # Checks for redirect and adds redirection target URL to Scanner
     def initialize(target, scanner, max_redirects)
       redirect_url = target.get_redirection_target
-      return if redirect_url.nil?
+
+      if redirect_url.nil?
+        debug("No valid redirect target found for #{target.target}")
+        return
+      end
 
       if target.redirect_counter >= max_redirects
         error("ERROR Too many redirects: #{target} => #{redirect_url}")
@@ -29,7 +32,7 @@ module WhatWeb
       end
 
       # pp target.redirect_counter, redirect_url
-      puts "redirect #{target.redirect_counter + 1} from #{target.target} to #{redirect_url}" if $verbose > 1
+      debug("redirect #{target.redirect_counter + 1} from #{target.target} to #{redirect_url}")
       scanner.add_target(redirect_url, target.redirect_counter + 1)
     end
   end
