@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "ACTi-Web-Configurator" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-04-27
+Plugin.define do
+name "ACTi-Web-Configurator"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-04-27
+]
 version "0.1"
 description "ACTi Web Configurator - camera web interface"
 website "http://www.acti.com/home/index.asp"
