@@ -2,15 +2,18 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2016-04-17 # Andrew Horton
-# Updated description
-##
-Plugin.define "Antiboard" do
-author "Andrew Horton"
-version "0.2"
-description "Antiboard is a PHP forum. Homepage used to be http://www.resynthesize.com/code/antiboard.php."
+Plugin.define do
+name "Antiboard"
+authors [
+  "Andrew Horton", 
+  # v0.2 # 2016-04-17 # Updated description. 
+  # Andrew Horton # v0.3 # 2019-07-10 # Added website field.
+]
+version "0.3"
+description "Antiboard is a PHP forum."
+website "http://www.resynthesize.com/code/antiboard.php"
 
 # Dorks #
 dorks [
