@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-01-08 #
-# Updated version detection
-##
-Plugin.define "Basilic" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-14
+Plugin.define do
+name "Basilic"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-14
+  # v0.2 # 2011-01-08 # Updated version detection. 
+]
 version "0.2"
 description "Basilic is a bibliography server for research laboratories. It automates and facilitates the diffusion of research publications over the internet, automatically generating web pages from a publication database."
 website "http://artis.imag.fr/Software/Basilic"
