@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Carrier-CCNWeb" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-03-06
+Plugin.define do
+name "Carrier-CCNWeb"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-03-06
+]
 version "0.1"
 description 'Carrier CCNWeb - a web-based HVAC front-end for a Carrier CCN Controls system. Comes out of the box with the ability to "Self-Learn" the building controls and then automatically display them."
 website "'
