@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "CitusCMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-06-23
+Plugin.define do
+name "CitusCMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-06-23
+]
 version "0.1"
 description "CitusCMS - Open Source Content Management System"
 website "http://www.citus-cms.org/"
