@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "DT-Centrepiece" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-06
+Plugin.define do
+name "DT-Centrepiece"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-06
+]
 version "0.1"
 description "DT Centrepiece is a free open-source content management system (CMS) for commercial or personal use."
 website "www.dt.net.nz/centrepiece/"
