@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "EasyFeeds" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-07-05
+Plugin.define do
+name "EasyFeeds"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-07-05
+]
 version "0.1"
 description "EasyFeeds is a powerful PHP based RSS reader and news aggregator."
 website "http://www.ktools.net/easyfeeds/"
