@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2
-# removed :name and :certainty=>100
-##
-Plugin.define "Echo" do
-author "Andrew Horton"
+Plugin.define do
+name "Echo"
+authors [
+  "Andrew Horton",
+  # v0.2 # removed :name and :certainty=>100. 
+]
 version "0.2"
 description "CMS"
 website "http://www.helloecho.com/"
