@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Enhydra-Application-Server" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-03-20
+Plugin.define do
+name "Enhydra-Application-Server"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-03-20
+]
 version "0.1"
 description "Enhydra Application Server"
 website "http://enhydra.org/"
