@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 
-# Fixed GHDB and regex matches
-##
-Plugin.define "FluentNET" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-08
+Plugin.define do
+name "FluentNET"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-08
+  # v0.2 # Fixed GHDB and regex matches. 
+]
 version "0.2"
 description "FluentNET, DotContent's powerful content management software, empowers business users to create, manage and publish web content for both general public access as well as internal use, and maximises the value of web-based information."
 website "http://www.dotcontent.net"
