@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Funkwerk-Gateway" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-11-24
+Plugin.define do
+name "Funkwerk-Gateway"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-11-24
+]
 version "0.1"
 description "Funkwerk Gateway"
 website "http://www.funkwerk-ec.com/"
