@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "GrandTec-X-Guard" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-05
+Plugin.define do
+name "GrandTec-X-Guard"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-05
+]
 version "0.1"
 description "GrandTec X-Guard PC-based surveillance system"
 website "http://store.grandtec.com/secsur.html"
@@ -16,7 +19,7 @@ website "http://store.grandtec.com/secsur.html"
 
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# HTTP Server Header
