@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Infotrak-Oil-Commander" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-06-27
+Plugin.define do
+name "Infotrak-Oil-Commander"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-06-27
+]
 version "0.1"
 description "Web-based system for managing oil samples through the laboratory process and presenting the results to customers."
 website "http://www.infotrak.com.au/"
