@@ -2,17 +2,15 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-
-
-# Version 0.2
-# removed :probability
-# Version 0.3
-# make powered by case insensitive, added 2nd example
-
-Plugin.define "ISPConfig" do
-author "Andrew Horton"
+Plugin.define do
+name "ISPConfig"
+authors [
+  "Andrew Horton",
+  # v0.2 # removed :probability
+  # v0.3 # make powered by case insensitive, added 2nd example
+]
 version "0.3"
 description "ISPConfig is a free, opensource hosting control panel"
 website "http://www.ispconfig.org/"
