@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Konica-Minolta-Printer" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-09-22
+Plugin.define do
+name "Konica-Minolta-Printer"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-09-22
+]
 version "0.1"
 description "Konica Minolta Printer"
 website "http://konicaminolta.com/"
