@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "M2Soft-RDServer" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-06-03
+Plugin.define do
+name "M2Soft-RDServer"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-06-03
+]
 version "0.1"
 description "M2Soft Report Designer Server - reporting tool"
 website "http://www.m2soft.co.kr/english/reporting-tool.asp"
