@@ -2,14 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2016-04-21 # Andrew Horton
-# Moved patterns from passive function to matches[]
-# added website parameter
-##
-Plugin.define "MacHTTP" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-06-04
+Plugin.define do
+name "MacHTTP"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-06-04
+  "Andrew Horton", # v0.2 # 2016-04-21 # Moved patterns from passive function to matches[]. added website parameter. 
+]
 version "0.2"
 description "MacHTTP is a webserver designed to run on Mac OS versions 7.x through 9.x. It was written by software developer Chuck Shotton and was originally shareware; it is now available in source code form from SourceForge.net under the Perl Artistic License. It is still used on some older Macintosh hardware. It was later commercialized as WebSTAR, sold originally by StarNine and later bought by Quarterdeck Software. - More Info: http://en.wikipedia.org/wiki/MacHTTP"
 website "http://www.machttp.org/downloads/machttp/"
