@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-02-18 #
-# Updated version detection
-##
-Plugin.define "MyioSoft-Ajax-Portal" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-14
+Plugin.define do
+name "MyioSoft-Ajax-Portal"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-14
+  # v0.2 # 2011-02-18 # Updated version detection. 
+]
 version "0.2"
 description "AjaxPortal is based on Sajax technology - an open source tool to make programming websites using the Ajax framework known as XMLHTTPRequest or remote scripting as easy as possible."
 website "http://myiosoft.com/"
@@ -32,7 +33,7 @@ matches [
 ]
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# ajaxp cookie
