@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "NexusPHP" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-07-01
+Plugin.define do
+name "NexusPHP"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-07-01
+]
 version "0.1"
 description "BitTorrent private tracker scripts written in PHP"
 website "http://sourceforge.net/projects/nexusphp/"
