@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Nortel-Ethernet-Routing-Switch-Config-File" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-10-14
+Plugin.define do
+name "Nortel-Ethernet-Routing-Switch-Config-File"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-10-14
+]
 version "0.1"
 description "Nortel Ethernet Routing Switch Config File"
 website "http://products.nortel.com/go/product_index.jsp?locale=en-US&lcid=-1"
@@ -13,7 +16,7 @@ website "http://products.nortel.com/go/product_index.jsp?locale=en-US&lcid=-1"
 # 21 results for "qos queue-set-assignment queue-set" @ 2010-10-14
 
 
-def passive
+passive do
 	m=[]
 
 	if @body =~ /qos queue-set-assignment queue-set/
