@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Owl-Intranet-Engine" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-08-30
+Plugin.define do
+name "Owl-Intranet-Engine"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-08-30
+]
 version "0.1"
 description "Owl is a multi user document repository (knowledge base) system written in PHP for publishing files/documents onto the web."
 website "http://owl.anytimecomm.com"
