@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "phpGraphy" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-05-06
+Plugin.define do
+name "phpGraphy"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-05-06
+]
 version "0.1"
 description "phpGraphy is a free PHP photo gallery script released under GPL license."
 website "http://phpgraphy.sourceforge.net/"
