@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "phpMumbleAdmin" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-04-08
+Plugin.define do
+name "phpMumbleAdmin"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-04-08
+]
 version "0.1"
 description "Php Mumble Admin is an administration panel control for murmur 1.2.0 and higher. It's communicate over ICE and It's designed for multiple servers."
 website "http://phpmumbleadmin.sourceforge.net/"
@@ -16,7 +19,7 @@ website "http://phpmumbleadmin.sourceforge.net/"
 
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# Set-Cookie: phpMumbleADMIN_session
