@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "PowerAlert" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-05-23
+Plugin.define do
+name "PowerAlert"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-05-23
+]
 version "0.1"
 description "PowerAlert monitors and controls UPS Systems, PDUs, sensors, and the computers and equipment they support."
 website "http://www.tripplite.com/en/products/poweralert-software.cfm"
@@ -25,7 +28,7 @@ matches [
 ]
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# HTTP Server Header
