@@ -2,16 +2,15 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.3 # 2011-02-15 # Brendan Coles < bcoles at gmail dot com >
-# Updated regex match
-##
-# Version 0.2
-# removed :certainty
-##
-Plugin.define "PoweredBy" do
-author "Andrew Horton"
+Plugin.define do
+name "PoweredBy"
+authors [
+  "Andrew Horton",
+  # v0.2 # removed :certainty. 
+  "Brendan Coles < bcoles@gmail.com>", # v0.3 # 2011-02-15 # Updated regex match. 
+]
 version "0.3"
 description "This plugin identifies instances of 'Powered by x' text and attempts to extract the value for x."
 
