@@ -2,11 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-
-Plugin.define "Profense-Firewall" do
-author "Aung Khant <http://yehg.net/>" # 2011-02-04
+Plugin.define do
+name "Profense-Firewall"
+authors [
+  "Aung Khant <http://yehg.net/>", # 2011-02-04
+]
 version "0.1"
 description "Profense Web Application Firewall -  http://www.armorlogic.com/profense_overview.html"
 
@@ -14,7 +16,7 @@ description "Profense Web Application Firewall -  http://www.armorlogic.com/prof
 
 
 
-def passive
+passive do
     m = []   
       
     m << {:name=>"PLBSID cookie" } if @headers["set-cookie"] =~ /PLBSID=/i  
