@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "qdPM" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-06-15
+Plugin.define do
+name "qdPM"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-06-15
+]
 version "0.1"
 description "qdPM is a free web-based project management tool suitable for a small team working on multiple projects."
 website "http://qdpm.net/"
