@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "RIPS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-03-25
+Plugin.define do
+name "RIPS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-03-25
+]
 version "0.1"
 description "RIPS - A static source code analyser for vulnerabilities in PHP scripts"
 website "http://sourceforge.net/projects/rips-scanner/"
