@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Simple-Directory-Listing" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-01
+Plugin.define do
+name "Simple-Directory-Listing"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-01
+]
 version "0.1"
 description "A php application that provides a web-based graphical interface similar to apache directory listing. Functions:copy, move, delete, rename files, etc."
 website "http://sourceforge.net/simpledirectory"
