@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Socorro" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-07
+Plugin.define do
+name "Socorro"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-07
+]
 version "0.1"
 description "A server for collecting, processing, and displaying crash reports from clients using the Breakpad libraries"
 website "code.google.com/p/socorro/"
