@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-03-02 #
-# Updated model detection
-##
-Plugin.define "Sony-Network-Camera" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-07-22
+Plugin.define do
+name "Sony-Network-Camera"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-07-22
+  # v0.2 # 2011-03-02 # Updated model detection. 
+]
 version "0.2"
 description "SONY network video camera web interface"
 website "http://www.sony.com/"
