@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Tab-and-Link-Manager" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-03-23
+Plugin.define do
+name "Tab-and-Link-Manager"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-03-23
+]
 version "0.1"
 description "The Tab And Link Manager engine is a total replacement for the default vBulletin NavBar"
 website "http://www.wolfshead-solutions.com/ws-products/product-1"
