@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-02-25 #
-# Updated version detection
-##
-Plugin.define "TaskFreak" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-07-10
+Plugin.define do
+name "TaskFreak"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-07-10
+  # v0.2 # 2011-02-25 # Updated version detection. 
+]
 version "0.2"
 description "TaskFreak! Original is a simple but efficient web based task manager written in PHP."
 website "http://www.taskfreak.com/original/"
