@@ -2,15 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-01-29 # Brendan Coles <bcoles@gmail.com>
-# Added model detection
-# Added HTTP server header match
-# Added 401 error match
-##
-Plugin.define "TP-Link-Router" do
-author "Aung Khant, http://yehg.net"
+Plugin.define do
+name "TP-Link-Router"
+authors [
+  "Aung Khant, http://yehg.net",
+  "Brendan Coles <bcoles@gmail.com>", # v0.2 # 2011-01-29 # Added model detection. Added HTTP server header match. Added 401 error match. 
+]
 version "0.2"
 description "Detect TP-Link Router"
 website "http://www.tp-link.com/"
@@ -32,7 +31,7 @@ matches [
 ]
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# HTTP Server Header
