@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 #
-# Updated version detection
-##
-Plugin.define "Trac" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-06-15
+Plugin.define do
+name "Trac"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-06-15
+  # v0.2 # Updated version detection. 
+]
 version "0.2"
 description "Trac is an enhanced wiki and issue tracking system for software development projects."
 website "http://trac.edgewall.org/"
@@ -33,7 +34,7 @@ matches [
 ]
 
 # Fingerprint cookie
-def passive
+passive do
         m=[]
 
         m << {:name=>"trac_form_token Cookie", :probability=>100 } if @headers["set-cookie"] =~ /trac_form_token=/
