@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "VMware-VirtualCenter" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-03-06
+Plugin.define do
+name "VMware-VirtualCenter"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-03-06
+]
 version "0.1"
 description "VMware VirtualCenter is a software suite designed to centralize the management of virtualized IT environments."
 website "http://www.vmware.com/products/vcenter-server/"
