@@ -2,14 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-
-# Version 0.2
-# removed :certainty=>100 & :name, convert :regexp to :text
-
-Plugin.define "XtraBusinessHosting" do
-author "Andrew Horton"
+Plugin.define do
+name "XtraBusinessHosting"
+authors [
+  "Andrew Horton",
+  # v0.2 # removed :certainty=>100 & :name, convert :regexp to :text
+]
 version "0.2"
 description "Hosting at Xtra.co.nz"
 
