@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "YouTube" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-04-16
+Plugin.define do
+name "YouTube"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-04-16
+]
 version "0.1"
 description "Embedded YouTube video"
 website "http://youtube.com/"
