@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Zikula" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-06-12
+Plugin.define do
+name "Zikula"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-06-12
+]
 version "0.1"
 description "Zikula is a Web Application Toolkit, which allows you to run impressive websites and build powerful online applications."
 website "http://zikula.org"
